//
//  Evernote.m
//  Evernote Demo
//
//  Created by Rie Hisao on 1/22/12.
//  Copyright (c) 2012 Santa Clara University. All rights reserved.
//

#import "Evernote.h"

// API Key - Put yours
NSString * const consumerKey  = @"";
NSString * const consumerSecret = @"";

NSString * const userStoreUri = @"https://sandbox.evernote.com/edam/user";
NSString * const noteStoreUriBase = @"https://sandbox.evernote.com/edam/note/";

NSString * const applicationName = @"Evernote Demo";
NSString * const applicationVersion = @"1.0";

@implementation Evernote

@synthesize user, shardId, authToken, username, password, noteStoreUri, noteStore;

// singleton
static Evernote *sharedEvernoteManager = nil;

+ (Evernote *)sharedInstance {
    
    if (sharedEvernoteManager == nil) {        
        sharedEvernoteManager = [[Evernote alloc] init];
    }
    
    return sharedEvernoteManager;
    
}

-(id)init {
    self = [super init];
    
    return self;
}

-(void) setLoginInfo: (NSString *) userId andPassword: (NSString *) pwd {
    username = userId;
    password = pwd;
    NSLog(@"Evernote: username = %@; pwd = %@", username, password);
}

-(void) connect {
    
    if (authToken == nil) 
    {      
        // In the case we are not connected we don't have an authToken
        // Instantiate the Thrift objects
        NSURL * NSURLuserStoreUri = [[[NSURL alloc] initWithString: userStoreUri] autorelease];
        
        THTTPClient *userStoreHttpClient = [[[THTTPClient alloc] initWithURL:  NSURLuserStoreUri] autorelease];
        TBinaryProtocol *userStoreProtocol = [[[TBinaryProtocol alloc] initWithTransport:userStoreHttpClient] autorelease];
        EDAMUserStoreClient *userStore = [[[EDAMUserStoreClient alloc] initWithProtocol:userStoreProtocol] autorelease];
        
        
        // Check that we can talk to the server
        bool versionOk = [userStore checkVersion: applicationName :[EDAMUserStoreConstants EDAM_VERSION_MAJOR] :    [EDAMUserStoreConstants EDAM_VERSION_MINOR]];
        
        if (!versionOk) {
            // Alerting the user that the note was created
            UIAlertView *alertDone = [[UIAlertView alloc] initWithTitle: @"Evernote" message: @"Incompatible EDAM client protocol version" delegate: self cancelButtonTitle: @"Ok" otherButtonTitles: nil];
            
            [alertDone show];
            [alertDone release];
            
            return;
        }
        
        
        // Returned result from the Evernote servers after authentication
        EDAMAuthenticationResult* authResult =[userStore authenticate:username :password : consumerKey :consumerSecret];
        
        // User object describing the account
        self.user = [authResult user];
        // We are going to save the authentication token
        self.authToken = [authResult authenticationToken];
        // and the shard id
        self.shardId = [user shardId];
        
        // Creating the user's noteStore's URL
        noteStoreUri =  [[[NSURL alloc] initWithString:[NSString stringWithFormat:@"%@%@", noteStoreUriBase, shardId] ] autorelease];
        
        // Creating the User-Agent
        UIDevice *device = [UIDevice currentDevice];
        NSString * userAgent = [NSString stringWithFormat:@"%@/%@;%@(%@)/%@", applicationName,applicationVersion, [device systemName], [device model], [device systemVersion]]; 
        
        
        // Initializing the NoteStore client
        THTTPClient *noteStoreHttpClient = [[[THTTPClient alloc] initWithURL:noteStoreUri userAgent: userAgent timeout:15000] autorelease];
        TBinaryProtocol *noteStoreProtocol = [[[TBinaryProtocol alloc] initWithTransport:noteStoreHttpClient] autorelease];
        noteStore = [[[EDAMNoteStoreClient alloc] initWithProtocol:noteStoreProtocol] retain];
        
    }
    NSLog(@"***** connected *****");
}

- (NSArray *) listTags {       
    // Checking the connection
    [self connect];
    
    // Calling a function in the API
    NSArray *tags = [[NSArray alloc] initWithArray:[[self noteStore] listTags:authToken]];
    
    return tags;
}

-(void) createTag: (EDAMTag *) tag {
    // Checking the connection
    [self connect];
    
    [[self noteStore] createTag:authToken :tag];
}

-(void) updateTag: (EDAMTag *) tag {
    // Checking the connection
    [self connect];
    
    [[self noteStore] updateTag:authToken :tag];
}

-(void) untagAll: (NSString *) guid {
    // Checking the connection
    [self connect];
    
    // Calling a function in the API
    [[self noteStore] untagAll:authToken :guid];
}

-(void) dealloc {
    [noteStore release];
    [super dealloc];
}
@end
