//
//  Tab2_TableViewController.m
//  Evernote Demo
//
//  Created by Rie Hisao on 1/20/12.
//  Copyright (c) 2012 Santa Clara University. All rights reserved.
//

#import "TagTableViewController.h"
#import "Evernote.h"
#import "Tag.h"

@implementation TagTableViewController
@synthesize tagData, indexArray;

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    tagData = [[NSMutableArray alloc] init];
    indexArray = [[NSMutableArray alloc] init];
    
    // Loading all tages in the logged-in account
    NSArray *userTags = (NSArray *)[[Evernote sharedInstance] listTags];
    
    NSLog(@"userTags count = %i", [userTags count]);
    
    // Filter tags by "name" key
    NSArray *tmp = [userTags valueForKey:@"name"];
    for (id obj in tmp) {
        [tagData addObjectsFromArray:tmp];
    }
    
    // Filter tags by "guid" key
    NSArray *tmp2 = [userTags valueForKey:@"guid"];
    for (id obj in tmp2) {
        [indexArray addObjectsFromArray:tmp2];
    }
    
    NSLog(@"guid = %@", indexArray);
 
    // Display an Edit button in the navigation bar for this view controller.
    self.navigationItem.rightBarButtonItem = self.editButtonItem;
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [self.tableView reloadData];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
    [super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    // Return the number of sections.
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    // Return the number of rows in the section.
    return [self.tagData count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier] autorelease];
    }
    
    // Configure the cell...
    NSUInteger row = [indexPath row];
    cell.textLabel.text = [self.tagData objectAtIndex:row];
    cell.textLabel.textColor = [UIColor darkGrayColor];
    NSLog(@"++++++ cell config: %@", cell.textLabel.text);
    return cell;
}

// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        NSLog(@"++++++ untagAll");
        NSUInteger row = [indexPath row];
        NSString *guid = [indexArray objectAtIndex:row];
        
        NSLog(@"indexPath = %i and guid = %@", row, guid);
        
        // Untag call
        [[Evernote sharedInstance] untagAll:guid];
        NSLog(@"++++++ untagAll done");
        
        [tagData removeObjectAtIndex:row];
        
        [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }   
}

-(void) dealloc
{
    [super dealloc];
    [tagData release];
    [indexArray release];
}

-(void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    if ([segue.identifier isEqualToString:@"AddTag"]) {
        UINavigationController *navController = segue.destinationViewController;
        TagDetailsViewController *tagDetailsViewController = [[navController viewControllers] objectAtIndex:0];
        tagDetailsViewController.delegate = self;
    }
}

#pragma mark - TagDetailsViewControllerDelegate
-(void) tagDetailsViewControllerDidCancel:(TagDetailsViewController *)controller
{
    [self dismissViewControllerAnimated:YES completion:nil];
}

-(void) tagDetailsViewController: (TagDetailsViewController *) controller didAddTag:(Tag *)tag
{
    // Create a tag
    EDAMTag *newTag = [[[EDAMTag alloc] init] autorelease];
    
    // Assign user input value
    newTag.name = tag.tagName;
    [[Evernote sharedInstance] createTag:newTag];
    //[[Evernote sharedInstance] updateTag:newTag];
    
    [self.tagData addObject:tag.tagName];
    
    NSIndexPath *indexPath = [NSIndexPath indexPathForRow:[self.tagData count]-1 inSection:0];
    [self.tableView insertRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationAutomatic];
    [self dismissViewControllerAnimated:YES completion:nil];
}

@end
